@@ -1,6 +1,6 @@
 def get_api_module():
     api_modules = (
-        "model2.user.main.service",
-        "model2.role.main.service"
+        "model2.user.main.Service",
+        "model2.role.main.Service"
     )
     return api_modules
\ No newline at end of file
